def print_hi(name):
    # Use a breakpoint in the code line below to debug your script.
    print(f'Hii, Hello {name}')  # Press ⌘F8 to toggle the breakpoint.


# Press the green button in the gutter to run the script.
if __name__ == '__main__':
    print_hi("I'm Tung")